@@ -1,8 +1,8 @@
 from ._version import __version__
 
 from .models import (
-    BartForSequenceClassification, DistilBertForMaskedLM, ElectraForSequenceClassification, RobertaForQuestionAnswering,
-    CoreferencePredictor
+    BartForSequenceClassification, Blender, CoreferencePredictor, DistilBertForMaskedLM,
+    ElectraForSequenceClassification, RobertaForQuestionAnswering
 )
 
 from .multiprocess_api import ClientAPI, ModelDeploymentConfig
