@@ -15,7 +15,7 @@ from .time_distributed import TimeDistributed
 from .coref_utils import (
     masked_topk, flatten_and_batch_shift_indices, batched_index_select, masked_softmax,
     weighted_sum, bucket_values)
-from ...utils import transposed_cat, neg_inf
+from ...utils import neg_inf
 
 
 class CoreferencePredictor(torch.nn.Module):
@@ -80,12 +80,16 @@ class CoreferencePredictor(torch.nn.Module):
         }
         state_dict['transformer.model.embeddings.word_embeddings.weight'] += state_dict.pop(
             'transformer.model.embeddings.token_type_embeddings.weight')[0]
+
+        scale = math.sqrt(self.transformer.model.encoder.layers[0].attention.dim_per_head)
+
         for layer_ind in range(len(self.transformer.model.encoder.layers)):
             prefix = f'transformer.model.encoder.layers.{layer_ind}.'
             for p in ('weight', 'bias'):
-                state_dict[f'{prefix}attention.pre_attention.{p}'] = transposed_cat([
+                state_dict[f'{prefix}attention.self.query.{p}'] /= scale
+                state_dict[f'{prefix}attention.pre_attention.{p}'] = torch.cat([
                     state_dict.pop(f'{prefix}attention.self.{k}.{p}') for k in ('query', 'key', 'value')
-                ])
+                ], dim=0)
                 for new_name, old_name in old_names.items():
                     state_dict[f'{prefix}{new_name}.{p}'] = state_dict.pop(f'{prefix}{old_name}.{p}')
         return super().load_state_dict(state_dict, strict)
