@@ -13,16 +13,7 @@ from transformers.modeling_outputs import BaseModelOutput, BaseModelOutputWithPa
 from transformers.generation_utils import GenerationMixin
 
 
-class Linear(torch.nn.Linear):
-    def __init__(self, in_features: int, out_features: int, bias: bool = True):
-        torch.nn.Module.__init__(self)
-        self.in_features = in_features
-        self.out_features = out_features
-        self.weight = nn.Parameter(torch.Tensor(out_features, in_features))
-        if bias:
-            self.bias = nn.Parameter(torch.Tensor(out_features))
-        else:
-            self.register_parameter('bias', None)
+from modules import Linear
 
 
 class T5LayerNorm(nn.Module):
