@@ -160,7 +160,7 @@ class ClientAPI:
 
             if added_connections:
                 preferred_batch_size = (total_batch_size - 1) // added_connections + 1
-                if preferred_batch_size > self.max_batch_size:
+                if self.max_batch_size is not None and preferred_batch_size > self.max_batch_size:
                     total_batch_size -= self.max_batch_size * added_connections
                     leftover_num = 0
                     batch_size = self.max_batch_size
