@@ -172,10 +172,12 @@ class ModelServer:
             try:
                 keys = list(inputs[0].keys())
                 sizes = [sample_inputs[keys[0]].shape[0] for sample_inputs in inputs]
+                print(f'INPUT LENGTHS: {sizes}')
                 inputs = {
                     key: self.pad_and_concat(list(map(itemgetter(key), inputs)), pad_map.get(key, 0))
                     for key in keys
                 }
+                print(f'CONCATTED SHAPE: {inputs[keys[0]].shape}')
                 with torch.no_grad():
                     outputs = self.model.forward(**inputs)
                 for session_state, output in zip(session_states, self.split_output(outputs, sizes)):
